@@ -19,6 +19,11 @@ logger = logging.getLogger(__name__)
 _counter = count(1)
 
 
+class NoOutput(Exception):
+    def __init__(self, *args: object) -> None:
+        super().__init__(*args)
+
+
 class PrefetchUnit(Process):
     def __init__(self, num_prefetch: int, gid: int, ignore_error: bool, processing_func: Optional[Callable[[Any], Any]] = None):
         """Prefetch Generator
@@ -212,6 +217,7 @@ class PrefetchGenerator(Thread):
                                 self._units[gid].terminate()
                             else:
                                 if self._ignore_error:
+                                    self.results[total_idx] = NoOutput
                                     logger.warning(item)
                                 else:
                                     logger.error(item)
@@ -259,9 +265,12 @@ class PrefetchGenerator(Thread):
                 # self.ordered=True 이면, self.results에서 next_idx를 꺼내고
                 # self.ordered=False 이면, popitem(False)로 가장 오래된 데이터부터 꺼냄
                 item = self.results.pop(self._next_idx) if self.ordered else self.results.popitem(False)[1]
-                self._pendding = False
-                self._next_idx +=1
-                return item
+                if item is NoOutput:
+                    continue
+                else:
+                    self._pendding = False
+                    self._next_idx +=1
+                    return item
             else:
                 # unit에서 데이터가 준비될때까지 대기하기 위해서 진입하는 조건문
                 # sleep이 없는 경우 불필요하게 자원을 많이 사용할 수 있어서 제약을 둠
